==> oracle-database-appliance_19.29.zip: oracle-database-appliance_19.29_20251125/content/cmtrx/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-C87C6CE4-2849-4753-BDFC-DD1A15C7060D"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Oracle Database Appliance Frequently Asked Questions",
                    "href":"oracle-database-appliance-faqs.html",
                    "topics":[
                        {
                            "title":"Patching Oracle Database Appliance",
                            "href":"faqs-patching-oracle-database-appliance.html"
                        },
                        {
                            "title":"TDE Keys on Oracle Key Vault for TDE-Enabled Databases",
                            "href":"faqs-oracle-key-vault.html"
                        },
                        {
                            "title":"Oracle Auto Service Request",
                            "href":"faqs-asr.html"
                        },
                        {
                            "title":"Updating Components using the odacli update-registry Command",
                            "href":"updating-components-using-odacli-update-registry-command.html"
                        },
                        {
                            "title":"Micronaut on Oracle Database Appliance",
                            "href":"faqs-micronaut-oracle-database-appliance.html"
                        },
                        {
                            "title":"Adaptive Classification and Redaction (ACR) on Oracle Database Appliance",
                            "href":"faqs-acr-oracle-database-appliance.html"
                        },
                        {
                            "title":"Multi-User Access on Oracle Database Appliance",
                            "href":"multi-user-access-oracle-database-appliance.html"
                        },
                        {
                            "title":"Integrated Oracle Data Guard",
                            "href":"faqs-integrated-oracle-data-guard.html"
                        },
                        {
                            "title":"Oracle Database Appliance DB Systems",
                            "href":"faqs-db-systems.html"
                        },
                        {
                            "title":"Multiple Databases in DB Systems",
                            "href":"faqs-multi-db-support-db-systems.html"
                        },
                        {
                            "title":"Application KVMs on Oracle Database Appliance",
                            "href":"faqs-application-kvms-oracle-database-appliance.html"
                        },
                        {
                            "title":"CPU Pools",
                            "href":"faqs-cpu-pools.html"
                        },
                        {
                            "title":"Oracle Database Appliance Networks",
                            "href":"faqs-oracle-database-appliance-networks.html"
                        },
                        {
                            "title":"Browser User Interface",
                            "href":"faqs-browser-user-interface.html"
                        },
                        {
                            "title":"Backup and Recovery",
                            "href":"faqs-backup-and-recovery.html"
                        },
                        {
                            "title":"ODACLI Commands",
                            "href":"faqs-odacli-commands.html"
                        }
                    ]
                }
            ]
        }
    ]
});

==> oracle-database-appliance_19.30.zip: oracle-database-appliance_19.30_20260224/content/cmtrx/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Preface",
                    "href":"preface.html#GUID-C87C6CE4-2849-4753-BDFC-DD1A15C7060D"
                },
                {
                    "title":"<span class=\"secnum\">1 </span> Oracle Database Appliance Frequently Asked Questions",
                    "href":"oracle-database-appliance-faqs.html",
                    "topics":[
                        {
                            "title":"Oracle Database Appliance Monthly Updates",
                            "href":"faqs-oracle-database-appliance-monthly-patching.html"
                        },
                        {
                            "title":"Patching Oracle Database Appliance",
                            "href":"faqs-patching-oracle-database-appliance.html"
                        },
                        {
                            "title":"TDE Keys on Oracle Key Vault for TDE-Enabled Databases",
                            "href":"faqs-oracle-key-vault.html"
                        },
                        {
                            "title":"Oracle Auto Service Request",
                            "href":"faqs-asr.html"
                        },
                        {
                            "title":"Updating Components using the odacli update-registry Command",
                            "href":"updating-components-using-odacli-update-registry-command.html"
                        },
                        {
                            "title":"Micronaut on Oracle Database Appliance",
                            "href":"faqs-micronaut-oracle-database-appliance.html"
                        },
                        {
                            "title":"Adaptive Classification and Redaction (ACR) on Oracle Database Appliance",
                            "href":"faqs-acr-oracle-database-appliance.html"
                        },
                        {
                            "title":"Multi-User Access on Oracle Database Appliance",
                            "href":"multi-user-access-oracle-database-appliance.html"
                        },
                        {
                            "title":"Integrated Oracle Data Guard",
                            "href":"faqs-integrated-oracle-data-guard.html"
                        },
                        {
                            "title":"Oracle Database Appliance DB Systems",
                            "href":"faqs-db-systems.html"
                        },
                        {
                            "title":"Multiple Databases in DB Systems",
                            "href":"faqs-multi-db-support-db-systems.html"
                        },
                        {
                            "title":"Application KVMs on Oracle Database Appliance",
                            "href":"faqs-application-kvms-oracle-database-appliance.html"
                        },
                        {
                            "title":"CPU Pools",
                            "href":"faqs-cpu-pools.html"
                        },
                        {
                            "title":"Oracle Database Appliance Networks",
                            "href":"faqs-oracle-database-appliance-networks.html"
                        },
                        {
                            "title":"Browser User Interface",
                            "href":"faqs-browser-user-interface.html"
                        },
                        {
                            "title":"Backup and Recovery",
                            "href":"faqs-backup-and-recovery.html"
                        },
                        {
                            "title":"Backup and Recovery Using Recovery Service",
                            "href":"faqs-recovery-service.html"
                        },
                        {
                            "title":"ODACLI Commands",
                            "href":"faqs-odacli-commands.html"
                        }
                    ]
                }
            ]
        }
    ]
});
